package com.fs.course.service;

import java.util.List;
import com.fs.course.domain.FsCourseDomainName;

/**
 * 课程短链域名Service接口
 * 
 * @author fs
 * @date 2024-10-09
 */
public interface IFsCourseDomainNameService 
{
    /**
     * 查询课程短链域名
     * 
     * @param id 课程短链域名主键
     * @return 课程短链域名
     */
    public FsCourseDomainName selectFsCourseDomainNameById(Long id);

    /**
     * 查询课程短链域名列表
     * 
     * @param fsCourseDomainName 课程短链域名
     * @return 课程短链域名集合
     */
    public List<FsCourseDomainName> selectFsCourseDomainNameList(FsCourseDomainName fsCourseDomainName);

    /**
     * 新增课程短链域名
     * 
     * @param fsCourseDomainName 课程短链域名
     * @return 结果
     */
    public int insertFsCourseDomainName(FsCourseDomainName fsCourseDomainName);

    /**
     * 修改课程短链域名
     * 
     * @param fsCourseDomainName 课程短链域名
     * @return 结果
     */
    public int updateFsCourseDomainName(FsCourseDomainName fsCourseDomainName);

    /**
     * 批量删除课程短链域名
     * 
     * @param ids 需要删除的课程短链域名主键集合
     * @return 结果
     */
    public int deleteFsCourseDomainNameByIds(Long[] ids);

    /**
     * 删除课程短链域名信息
     * 
     * @param id 课程短链域名主键
     * @return 结果
     */
    public int deleteFsCourseDomainNameById(Long id);
}
